Package: multcompView
Type: Package
Title: Visualizations of Paired Comparisons
Version: 0.1-11
Authors@R: c(
    person("Spencer", "Graves", role = "aut"),
    person("Hans-Peter", "Piepho", role = "aut"),
    person("Luciano", "Selzer", email = "luciano.selzer@gmail.com", role = c("aut", "cre")),
    person("Sundar", "Dorai-Raj", role = "ctb"))
Description: Convert a logical vector or a vector of p-values or a correlation,
    difference, or distance matrix into a display identifying the pairs for
    which the differences were not significantly different. Designed for use
    in conjunction with the output of functions like TukeyHSD, dist (stats),
    simint, simtest, csimint, csimtest (multcomp), friedmanmc, kruskalmc (pgirmess).
License: GPL-2
Imports: grid
Suggests: multcomp, pgirmess, MASS
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-02-15 18:53:35 UTC; lucia
Author: Spencer Graves [aut],
  Hans-Peter Piepho [aut],
  Luciano Selzer [aut, cre],
  Sundar Dorai-Raj [ctb]
Maintainer: Luciano Selzer <luciano.selzer@gmail.com>
Repository: CRAN
Date/Publication: 2026-02-16 06:50:09 UTC
Built: R 4.6.0; ; 2026-04-25 16:08:37 UTC; unix
